@@ -13,15 +13,19 @@
 # limitations under the License.
 
 import json
+import tempfile
 from collections import defaultdict
 from logging import getLogger
 from math import exp
 
+from pathlib import Path
 from overrides import overrides
 
+from deeppavlov.core.common.file import read_yaml
 from deeppavlov.core.common.registry import register
 from deeppavlov.core.models.component import Component
 from deeppavlov.core.models.serializable import Serializable
+from deeppavlov.dataset_readers.md_yaml_dialogs_reader import MD_YAML_DialogsDatasetReader, DomainKnowledge
 
 log = getLogger(__name__)
 
@@ -125,7 +129,10 @@ class SlotFillingComponent(Component, Serializable):
 
         # base cases
         if m == 1:
-            return needle not in haystack
+            not_found = needle not in haystack
+            not_found = float(not_found)  # float required by the method usage
+            occurrence_ix = 0 if not_found else haystack.index(needle)
+            return not_found, occurrence_ix
         if not n:
             return m
 
@@ -152,3 +159,23 @@ class SlotFillingComponent(Component, Serializable):
                     j_min = j
                 # d = min(d, row1[j])
         return d, j_min
+
+
+@register('slotfill_raw_rasa')
+class RASA_SlotFillingComponent(SlotFillingComponent):
+    """wraps SlotFillingComponent so that it takes the slotfilling info from RASA configs"""
+
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
+
+    def save(self):
+        pass
+
+    def load(self, *args, **kwargs):
+        """reads the slotfilling info from RASA-styled dataset"""
+        domain_path = Path(self.load_path, MD_YAML_DialogsDatasetReader.DOMAIN_FNAME)
+        nlu_path = Path(self.load_path, MD_YAML_DialogsDatasetReader.NLU_FNAME)
+        domain_knowledge = DomainKnowledge(read_yaml(domain_path))
+        # todo: rewrite MD_YAML_DialogsDatasetReader so that public methods are enough
+        _, slot_name2text2value = MD_YAML_DialogsDatasetReader._read_intent2text_mapping(nlu_path, domain_knowledge)
+        self._slot_vals = slot_name2text2value
